Welcome to ClientVPS Mirrors

Help for package radous
Type: Package
Title: Query Random User Data from the Random User Generator API
Version: 0.1.3
Author: Mohamed El Fodil Ihaddaden
Maintainer: Mohamed El Fodil Ihaddaden <ihaddaden.fodeil@gmail.com>
Description: Generate random user data from the Random User Generator API. For more information, see https://randomuser.me/.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: glue, httr, readr, checkmate, curl
RoxygenNote: 7.1.1
URL: https://github.com/feddelegrand7/radous
BugReports: https://github.com/feddelegrand7/radous/issues
Suggests: testthat, covr
NeedsCompilation: no
Packaged: 2021-05-23 18:37:17 UTC; Administrateur
Repository: CRAN
Date/Publication: 2021-05-23 18:50:03 UTC

Query random user data from the Random User Generator API

Description

Query random user data from the Random User Generator API

Usage

get_data(n = 1, seed = NULL)

Arguments

n

Number of users to fetch, up to 5,000 generated users in one request. Defaults to 1

seed

A character string used to generate the same set of users. Defaults to NULL.

Value

A tibble that contains random user data

Examples


get_data(n = 10, seed = "1990")

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.